IV.RdCalculate information value
IV(splitted_labels)
| splitted_labels | A list of binary factors |
|---|
It is assumed, that y are splitted labels of a greater dataset. When combined together, they should form a vector equivalent to labels in original dataset (order may differ).