information_gain.RdBased on changed entropy of the data, calculated information gain.
information_gain(splitted_labels)
| splitted_labels | A list. Each element of it is a factor of labels. |
|---|
It is assumed, that y are splitted labels of a greater dataset. When combined together, they should form a vector equivalent to labels in original dataset (order may differ).